/////////////////////////////////////////////////////////////////////////////////////////
//
// 1-Wire Library V1 Project example
//
// --------------------------------------------------------------------------------------
//
// Filename:      main.c
// Version:       1.2
// Date:          31/07/2012
// Author:        Joel Guittet - http://myfreescalewebpage.free.fr
//
/////////////////////////////////////////////////////////////////////////////////////////
//
// Description
//
// This project example uses a DS18B20 temperature sensor from Dallas/Maxim Semiconductors
// to show a very simple implementation of the 1-wire protocol.
// The 1-wire functions can be used with any 1-wire devices and any microcontrollers,
// there is no need except, of course, a simple GPIO to connect the 1-wire device.
//
/////////////////////////////////////////////////////////////////////////////////////////
//
// Revisions
//
// Version	| Author		| Description
// --------------------------------------------------------------------------------------
// 1.0      | Joel Guittet  | Initial Release
// 1.1      | Joel Guittet  | Coding improvements
// 1.1      | Joel Guittet  | Modifications to use "typedef.h"
// 1.2      | Joel Guittet  | Coding improvements
//
/////////////////////////////////////////////////////////////////////////////////////////


//---------------------------------------------------------------------------------------
// Includes
//---------------------------------------------------------------------------------------

#include <hidef.h>
#include "derivative.h"
#include "ds18b20.h"


//---------------------------------------------------------------------------------------
// Prototypes
//---------------------------------------------------------------------------------------

static void InitCPU(void);
static void InitMCG(void);
static void InitGPIO(void);


//---------------------------------------------------------------------------------------
// Name:        main
// Param:		-
// Return:      -
//
// Description:	Main function, never return
//---------------------------------------------------------------------------------------
void main(void)
{
	UINT16 u16Index, u16Temperature;
	t_OneWireResetResult xDS18B20Status = NO_DEVICE_DETECTED;
		
	/* Initializations */
	InitCPU();
	
	/* Initialize the DS18B20 sensor, temperature resolution set to 9bits */
	xDS18B20Status = DS18B20_Init(9);

	EnableInterrupts;

	/* Main loop */
	for(;;)
	{
		/* Initiate a new temperature conversion (take up to 94ms) */
		xDS18B20Status = DS18B20_ConvertT();
		
		/* Make a small delay */
		for (u16Index = 0; u16Index < 65535; u16Index++);
		
		/* Now read the temperature */
		xDS18B20Status = DS18B20_ReadT(&u16Temperature);
		
		/* Make a small delay */
		for (u16Index = 0; u16Index < 65535; u16Index++);

		__RESET_WATCHDOG();
	}
}


//---------------------------------------------------------------------------------------
// Name:        InitCPU
// Param:		-
// Return:      -
//
// Description:	Initialize CPU
//---------------------------------------------------------------------------------------
static void InitCPU(void)
{
	InitMCG();
	InitGPIO();
}


//---------------------------------------------------------------------------------------
// Name:        InitMCG
// Param:    	-
// Return:      -
//
// Description:	MCG configuration: Crystal=12MHz, Fbus = 18MHz
//---------------------------------------------------------------------------------------
static void InitMCG(void)
{
	MCGC2 = 0x36;
	while(MCGSC_OSCINIT != 1);
	MCGC1 = 0xB8;
	while(MCGSC_IREFST != 0);
	while(MCGSC_CLKST != 0b10);  
	MCGC1 = 0x98;
	MCGC3 = 0x46;
	while(MCGSC_PLLST != 1);
	while(MCGSC_LOCK != 1);
	MCGC1 = 0x18;
	while(MCGSC_CLKST != 0b11);
}


//---------------------------------------------------------------------------------------
// Name:        InitGPIO
// Param:    	-
// Return:      -
//
// Description:	IO ports initialization
//---------------------------------------------------------------------------------------
static void InitGPIO(void)
{
}
