/////////////////////////////////////////////////////////////////////////////////////////
//
// 1-Wire Library V2
//
// --------------------------------------------------------------------------------------
//
// Filename:      1-wire.h 
// Version:       2.0
// Date:          01/11/2011
// Author:        Joel Guittet - http://myfreescalewebpage.free.fr
//
/////////////////////////////////////////////////////////////////////////////////////////
//
// Revisions
//
// Version	| Author		| Description
// --------------------------------------------------------------------------------------
// 2.0      | Joel Guittet  | Initial Release
//
/////////////////////////////////////////////////////////////////////////////////////////


#ifndef ONEWIRE_H_
#define ONEWIRE_H_


//---------------------------------------------------------------------------------------
// Include
//---------------------------------------------------------------------------------------

#include <hidef.h>
#include "derivative.h"
#include "typedef.h"


//---------------------------------------------------------------------------------------
// Definitions
//---------------------------------------------------------------------------------------

/* MCU Clock Frequency used by 1-Wire functions (MHz) (can be modified) */
#define BUSCLK             					18

/* 1-Wire Delay macro - 'Delay' value must be given in micro-seconds (maximum value: 3640s @ 18MHz) */
#define ONEWIRE_DELAY(u16Delay)				TPM1MOD = u16Delay * BUSCLK; 				\
											TPM1SC = 0b00001000; 						\
											while(!TPM1SC_TOF){__RESET_WATCHDOG();}		\
											TPM1SC &= 0x7F;                          	\
											TPM1SC = 0x00;

/* 1-Wire interface definition */
typedef struct
{
	UINT8 * PortData;
	UINT8 * PortDataDirection;
	UINT8 Bit;
}
t_OneWireInterface;

/* 1-Wire Reset result, used to know the current device status */
typedef enum
{
	NO_DEVICE_DETECTED,
	DEVICE_PRESENT,
	DEVICE_SHORTED
}
t_OneWireResetResult;


//---------------------------------------------------------------------------------------
// Prototypes
//---------------------------------------------------------------------------------------

void ONEWIRE_Init(t_OneWireInterface * pxInterface);
t_OneWireResetResult ONEWIRE_Reset(t_OneWireInterface * pxInterface);
void ONEWIRE_WriteByte(t_OneWireInterface * pxInterface, UINT8 u8Byte);
UINT8 ONEWIRE_ReadByte(t_OneWireInterface * pxInterface);
void ONEWIRE_SetStrongPullUp(t_OneWireInterface * pxInterface);


#endif
